from datetime import datetime
from typing import Mapping, Sequence

DAY_VALUE: str
HOUR_VALUE: str
MINUTE_VALUE: str
SECOND_VALUE: str
SIMPLE_VALUE: str
BASIC_VALUE: str
EXTENDED_VALUE: str
EXTENDED_SIMPLE_VALUE: str
MINIMIZE_MULTIPLE: str
MINIMIZE_UNIQUE: str
DEFAULT_INCLUDES: tuple[str, str, str, str]
DEFAULT_FORMAT: str
FORMATS: Mapping[str, Mapping[str, str]]
SEPARATORS: dict[str, str]

def format_seconds_smart(
    seconds: int, mode: str = ..., includes: Sequence[str] = ..., minimize: str = ...
) -> str: ...
def format_seconds(seconds: int, format_string: str = ...) -> str: ...
def timestamp_datetime(timestamp_string: str) -> datetime: ...



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Colony Framework
# Copyright (c) 2008-2024 Hive Solutions Lda.
#
# This file is part of Hive Colony Framework
#
# Hive Colony Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Colony Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Colony Framework If not, see <http://www.apache.org/licenses/>.

__author__ = "Hugo Gomes <hugo@frontdoorhq.com>"
""" The author(s) of the module """

__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import unittest

import colony


class VarsTest(unittest.TestCase):
    def test_set_global(self):
        colony.set_global("test_var", 42)
        result = colony.get_global("test_var")
        self.assertEqual(result, 42)

    def test_get_global_existing(self):
        colony.set_global("existing_var", "Hello, World!")
        result = colony.get_global("existing_var")
        self.assertEqual(result, "Hello, World!")

    def test_get_global_default(self):
        result = colony.get_global("non_existing_var", "Default Value")
        self.assertEqual(result, "Default Value")

    def test_get_global_no_default(self):
        result = colony.get_global("non_existing_var")
        self.assertIsNone(result)

    def test_get_global_existing_default(self):
        colony.set_global("existing_var", "Hello, World!")
        result = colony.get_global("existing_var", "Default Value")
        self.assertEqual(result, "Hello, World!")

    def test_has_global_existing(self):
        colony.set_global("existing_var", "Hello, World!")
        result = colony.has_global("existing_var")
        self.assertTrue(result)

    def test_has_global_non_existing(self):
        result = colony.has_global("non_existing_var")
        self.assertFalse(result)

    def test_has_global_with_none(self):
        colony.set_global("none_var", None)
        result = colony.has_global("none_var")
        self.assertTrue(result)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Colony Framework
# Copyright (c) 2008-2024 Hive Solutions Lda.
#
# This file is part of Hive Colony Framework
#
# Hive Colony Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Colony Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Colony Framework If not, see <http://www.apache.org/licenses/>.

__author__ = "Hugo Gomes <hugo@frontdoorhq.com>"
""" The author(s) of the module """

__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

GLOBALS = {}


def set_global(name, value):
    """
    Sets a global variable with the given name and value.

    :param name: The name of the global variable.
    :param value: The value to assign to the global variable.
    """
    GLOBALS[name] = value


def get_global(name, default=None):
    """
    Returns the value of a global variable,
    if found, otherwise the default value.

    :param name: The name of the global variable.
    :param default: The default value to return if
    the global variable is not found.
    :return: The value of the global variable if found,
    otherwise the default value.
    """
    return GLOBALS.get(name, default)


def has_global(name):
    """
    Checks if a global variable with the given name exists.

    :param name: The name of the global variable to check.
    :type name: str
    :return: True if the global variable exists, False otherwise.
    :rtype: bool
    """
    return name in GLOBALS



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Colony Framework
# Copyright (c) 2008-2024 Hive Solutions Lda.
#
# This file is part of Hive Colony Framework
#
# Hive Colony Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Colony Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Colony Framework If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import tempfile
import colony


class PathTest(colony.ColonyTestCase):
    """
    Class that tests the utility functions that
    are associated with path manipulation.
    """

    def test_ensure_file_path(self):
        """
        Tests the ensure_file_path function to verify it correctly
        handles file creation and copying from default file.
        """

        if not hasattr(tempfile, "TemporaryDirectory"):
            self.skipTest("TemporaryDirectory is not available")

        with tempfile.TemporaryDirectory() as temp_dir:
            default_file_path = os.path.join(temp_dir, "default.txt")
            default_content = b"Default content for ensure_file_path"
            with open(default_file_path, "wb") as file:
                file.write(default_content)

            target_file_path = os.path.join(temp_dir, "new", "target.txt")
            colony.ensure_file_path(target_file_path, default_file_path)

            self.assertTrue(os.path.exists(target_file_path))
            with open(target_file_path, "rb") as file:
                content = file.read()
            self.assertEqual(content, default_content)

            existing_content = b"Existing content"
            with open(target_file_path, "wb") as file:
                file.write(existing_content)

            colony.ensure_file_path(target_file_path, default_file_path)

            with open(target_file_path, "rb") as file:
                content = file.read()
            self.assertEqual(content, existing_content)

            deep_target_path = os.path.join(
                temp_dir, "deep", "nested", "path", "file.txt"
            )
            colony.ensure_file_path(deep_target_path, default_file_path)

            self.assertTrue(os.path.exists(deep_target_path))
            with open(deep_target_path, "rb") as file:
                content = file.read()
            self.assertEqual(content, default_content)



from colony.base import exceptions as exceptions

def verify(
    condition,
    message: str | None = ...,
    code: int | None = ...,
    exception: Exception | None = ...,
    **kwargs
) -> None: ...
def verify_equal(
    first,
    second,
    message: str | None = ...,
    code: int | None = ...,
    exception: Exception | None = ...,
    **kwargs
) -> None: ...
def verify_not_equal(
    first,
    second,
    message: str | None = ...,
    code: int | None = ...,
    exception: Exception | None = ...,
    **kwargs
) -> None: ...
def verify_type(
    value,
    types,
    null: bool = ...,
    message: str | None = ...,
    code: Exception | None = ...,
    exception: Exception | None = ...,
    **kwargs
) -> None: ...
def verify_many(
    sequence,
    message: str | None = ...,
    code: int | None = ...,
    exception: Exception | None = ...,
    **kwargs
) -> None: ...



from threading import Thread
from typing import Any, Callable, Sequence

class UpdateThread(Thread):
    stop_flag: bool
    timeout: int
    call_method: Callable
    call_arguments: Sequence[Any]
    daemon: bool

    def __init__(self) -> None: ...
    def stop(self) -> None: ...
    def get_timeout(self) -> int: ...
    def set_timeout(self, timeout: int) -> None: ...
    def get_call_method(self) -> Callable: ...
    def set_call_method(self, call_method: Callable) -> None: ...
    def get_call_arguments(self) -> Sequence[Any]: ...
    def set_call_arguments(self, call_arguments: Sequence[Any]) -> None: ...
    def run(self) -> None: ...
